View source: R/air_formatter.R
| air_install | R Documentation |
checks for air installation status and installs it if required (or if the installed version is older than the minimum supported version), updating the global settings if selected
air_install(update_rstudio_settings = FALSE, verbose = TRUE, force = FALSE)
update_rstudio_settings |
auto update RStudio settings |
verbose |
Run in verbose mode |
force |
force (re)installation of Air, even if an up to date version is already installed |
No return value, called for side effects
## Not run:
air_install()
## End(Not run)
Add the following code to your website.
For more information on customizing the embed code, read Embedding Snippets.