check_databricks_odbc: Check Databricks ODBC connection variables

View source: R/check_databricks_odbc.R

check_databricks_odbcR Documentation

Check Databricks ODBC connection variables

Description

Checks if the required environment variables for connecting to Databricks are set, and if the odbc package version is sufficient.

Usage

check_databricks_odbc()

Details

Prints instructions for fixing common problems to the console.

Value

TRUE if the connection is set up correctly, FALSE otherwise.

See Also

Other databricks: write_df_to_delta()

Examples

check_databricks_odbc()

dfeR documentation built on Sept. 24, 2026, 1:07 a.m.