View source: R/diagnostic_test.R
| check_git_sslverify | R Documentation |
Checks the values of the SSL-verify settings in the global Git config. If
they're set to false, the function flips them back to TRUE when called
with clean = TRUE. By default it checks http.sslVerify and
https.sslVerify.
check_git_sslverify(
ssl_verify_vars = c("http.sslverify", "https.sslverify"),
clean = FALSE
)
ssl_verify_vars |
Vector of variables to check for in the Git config. |
clean |
If |
Each check returns a list including a status field, one of "pass",
"fail", "fixed" or "info", depending on the outcome of the check.
List of sslverify settings plus a status field.
check_git_sslverify()
Add the following code to your website.
For more information on customizing the embed code, read Embedding Snippets.