View source: R/diagnostic_test.R
| check_renv_download_method | R Documentation |
The renv package can retrieve packages either using curl or wininet, but
wininet doesn't work from within the DfE network. This function checks
for the parameter controlling which of these is used
(RENV_DOWNLOAD_METHOD) in the user's .Renviron and sets it to curl
when called with clean = TRUE.
check_renv_download_method(renviron_file = "~/.Renviron", clean = FALSE)
renviron_file |
Location of |
clean |
If |
Each check returns a list including a status field, one of "pass",
"fail", "fixed" or "info", depending on the outcome of the check.
List object containing RENV_DOWNLOAD_METHOD (with surrounding
whitespace and any wrapping quotes stripped, or NA if the variable is
not set) plus a status field.
check_renv_download_method()
Add the following code to your website.
For more information on customizing the embed code, read Embedding Snippets.