fetch_lsips: Fetch Local Skills Improvement Plan (LSIP) areas lookup

View source: R/fetch.R

fetch_lsipsR Documentation

Fetch Local Skills Improvement Plan (LSIP) areas lookup

Description

Fetch a data frame of Local Skills Improvement Plan (LSIP) areas for a given year based on dfeR::lsip_lad.

Usage

fetch_lsips(year = "All")

Arguments

year

year to filter the locations to, default is "All", options of 2023 or 2025. ONS did not publish a 2024 lookup, so 2024 is not a valid option

Value

data frame of LSIP for a given year.

See Also

Other fetch_locations: fetch_countries(), fetch_lads(), fetch_las(), fetch_mayoral(), fetch_regions(), fetch_wards()

Examples


# Using head() to show only top 5 rows for examples
head(fetch_wards())

head(fetch_pcons())

head(fetch_pcons(2023))

head(fetch_pcons(countries = "Scotland"))

head(fetch_pcons(year = 2023, countries = c("England", "Wales")))

head(fetch_mayoral())

head(fetch_lsips())

head(fetch_lsips(2025))

fetch_lads(2024, "Wales")

fetch_las(2022, "Northern Ireland")

# The following have no specific years available and return all values
fetch_regions()
fetch_countries()

dfeR documentation built on Sept. 24, 2026, 1:07 a.m.