fetch_regions: Fetch regions

View source: R/fetch.R

fetch_regionsR Documentation

Fetch regions

Description

Fetch a data frame of all regions based on the dfeR::regions file.

Usage

fetch_regions()

Value

data frame of unique location names and codes

See Also

Other fetch_locations: fetch_countries(), fetch_lads(), fetch_las(), fetch_lsips(), fetch_mayoral(), fetch_wards()

Examples


# Using head() to show only top 5 rows for examples
head(fetch_wards())

head(fetch_pcons())

head(fetch_pcons(2023))

head(fetch_pcons(countries = "Scotland"))

head(fetch_pcons(year = 2023, countries = c("England", "Wales")))

head(fetch_mayoral())

head(fetch_lsips())

head(fetch_lsips(2025))

fetch_lads(2024, "Wales")

fetch_las(2022, "Northern Ireland")

# The following have no specific years available and return all values
fetch_regions()
fetch_countries()

dfeR documentation built on Sept. 24, 2026, 1:07 a.m.