| format_fy_reverse | R Documentation |
This function converts financial year variables back into 201617 format.
format_fy_reverse(year)
year |
Financial year, a single value or a vector |
It accepts character arguments.
Character vector of unformatted 6 digit years
Other format:
format_ay(),
format_ay_reverse(),
format_fy()
format_fy_reverse("2016-17")
format_fy_reverse(c("2016-17", "2017-18"))
Add the following code to your website.
For more information on customizing the embed code, read Embedding Snippets.