| geo_hierarchy | R Documentation |
A lookup showing the hierarchy of ward to Westminster parliamentary constituency to local authority district to local authority to combined mayoral authority to region to country for years 2017, 2019, 2020, 2021, 2022, 2023, 2024 and 2025.
geo_hierarchy
geo_hierarchyA data frame with 26,057 rows and 17 columns:
First year in the lookups that we see this location
Last year in the lookups that we see this location
Ward name
Parliamentary constituency name
Local authority district name
Local authority name
Mayoral authority name
Region name
Country name
9 digit ward code
9 digit westminster constituency code
9 digit local authority district code
old 3 digit local authority code
9 digit local authority code
9 digit combined authority code
9 digit region code
9 digit country code
Note that combined mayoral authorities only exist in England, and we use
english_devolved_area_name and english_devolved_area_code to refer
to mayoral authorities in line with the standards set in DfE official
statistics. Greater London Authority is not included in the ONS combined
authority lookup, we have added that in for all local authority districts
with codes that start with E090....
Changes we've made to the original lookup:
The original lookup from ONS uses the Upper Tier Local Authority, we then update this so that where there is a metropolitan local authority we use the local authority district as the local authority to match how DfE publish data for local authorities.
We have noticed that in the 2017 version, the Glasgow East constituency had a code of S1400030 instead of the usual S14000030, we've assumed this was an error and have change this in our data so that Glasgow East is S14000030 in 2017.
We have joined on regions using the Ward to LAD to County to Region file.
We have joined on countries based on the E / N / S / W at the start of codes.
Scotland had no published regions in 2017, so given the rest of the years have Scotland as the region, we've forced that in for 2017 too to complete the data set.
We've added the Greater London Authority as the overarching mayoral
authority (English devolved area) for all Local authority districts with
codes that start E090....
https://geoportal.statistics.gov.uk/search?tags=lup_wd_pcon_lad_utla https://geoportal.statistics.gov.uk/search?q=lup_wd_lad_cty_rgn_gor_ctry https://geoportal.statistics.gov.uk/search?tags=LUP_LAD_CAUTH https://get-information-schools.service.gov.uk/Guidance/LaNameCodes and https://tinyurl.com/EESScreenerLAs
Add the following code to your website.
For more information on customizing the embed code, read Embedding Snippets.