get_air_path: Get the expected Air executable path for the current platform

View source: R/air_formatter.R

get_air_pathR Documentation

Get the expected Air executable path for the current platform

Description

works out the platform-specific Air executable name and expected install location (in ⁠~/.local/bin/⁠), returning both alongside the resolved home directory and full path to the executable.

Usage

get_air_path()

dfeR documentation built on Sept. 24, 2026, 1:07 a.m.