Skip to contents

checks for air installation status and installs it if required (or if the installed version is older than the minimum supported version), updating the global settings if selected

Usage

air_install(update_rstudio_settings = FALSE, verbose = TRUE, force = FALSE)

Arguments

update_rstudio_settings

auto update RStudio settings

verbose

Run in verbose mode

force

force (re)installation of Air, even if an up to date version is already installed

Value

No return value, called for side effects

Examples

if (FALSE) { # \dontrun{
air_install()
} # }