View source: R/check_databricks_odbc.R
| check_databricks_odbc | R Documentation |
Checks if the required environment variables for connecting to
Databricks are set, and if the odbc package version is sufficient.
check_databricks_odbc()
Prints instructions for fixing common problems to the console.
TRUE if the connection is set up correctly, FALSE otherwise.
Other databricks:
write_df_to_delta()
check_databricks_odbc()
Add the following code to your website.
For more information on customizing the embed code, read Embedding Snippets.