The renv package can retrieve packages either using curl or wininet, but
wininet doesn't work from within the DfE network. This function checks
for the parameter controlling which of these is used
(RENV_DOWNLOAD_METHOD) in the user's .Renviron and sets it to curl
when called with clean = TRUE.
Value
List object containing RENV_DOWNLOAD_METHOD (with surrounding
whitespace and any wrapping quotes stripped, or NA if the variable is
not set) plus a status field.