View source: R/diagnostic_test.R
| diagnostic_test | R Documentation |
Run a set of diagnostic tests to check for common issues found when setting
up R on a DfE system. The function runs each check_*() helper in turn and
returns a combined list of detected settings. Problems can optionally be
fixed by passing clean = TRUE.
The checks include:
Proxy settings in the Git configuration and system environment
(check_proxy_settings())
Git SSL-verify setting (check_git_sslverify())
The location of the global .gitconfig file
(check_gitconfig_location())
The GITHUB_PAT system variable (check_github_pat())
renv download method in .Renviron (check_renv_download_method())
The RENV_DOWNLOAD_FILE_METHOD system variable
(check_renv_dl_file_method())
Presence of an RTools/make toolchain (check_rtools())
The location of .Renviron and .Rprofile
(check_renv_rprof_location())
diagnostic_test(clean = FALSE, full = FALSE)
clean |
If |
full |
If |
Each check returns a list including a status field, one of "pass",
"fail", "fixed" or "info", depending on the outcome of the check.
Invisibly, a named list keyed by check (proxy, sslverify,
gitconfig, github_pat, renv_download, renv_download_file,
rtools, renviron_rprofile). Each entry is the result list returned by
the corresponding check_* helper, plus a status field.
diagnostic_test()
Add the following code to your website.
For more information on customizing the embed code, read Embedding Snippets.