| fetch_mayoral | R Documentation |
Fetch a data frame of all mayoral combined authorities for a given year and country based on the dfeR::geo_hierarchy file.
fetch_mayoral(year = "All")
year |
year to filter the locations to, default is "All", options of 2017, 2019, 2020, 2021, 2022, 2023, 2024, 2025 |
Note that mayoral combined authorities only exist for England.
Mayoral combined authorities are also known as English Devolved Areas, as we add in the Greater London Authority to the combined authority lookup published by ONS.
data frame of unique location names and codes
Other fetch_locations:
fetch_countries(),
fetch_lads(),
fetch_las(),
fetch_lsips(),
fetch_regions(),
fetch_wards()
# Using head() to show only top 5 rows for examples
head(fetch_wards())
head(fetch_pcons())
head(fetch_pcons(2023))
head(fetch_pcons(countries = "Scotland"))
head(fetch_pcons(year = 2023, countries = c("England", "Wales")))
head(fetch_mayoral())
head(fetch_lsips())
head(fetch_lsips(2025))
fetch_lads(2024, "Wales")
fetch_las(2022, "Northern Ireland")
# The following have no specific years available and return all values
fetch_regions()
fetch_countries()
Add the following code to your website.
For more information on customizing the embed code, read Embedding Snippets.