This function formats academic year variables for reporting purposes. It will convert an academic year input from 201516 format to 2015/16 format.
See also
Other format:
format_ay_reverse(),
format_fy(),
format_fy_reverse()
Examples
format_ay(201617)
#> [1] "2016/17"
format_ay("201617")
#> [1] "2016/17"
format_ay(c(201617, 201718))
#> [1] "2016/17" "2017/18"